Default configuration templates
===============================

This directory contains the default configuration templates for the various pipelines.

The templates are written using the liquidpy templating language.

